var separate = 'separate';
const x = 2;
console.log('separate');

export { separate as default, x };
